import 'package:flutter/material.dart';
import 'package:flutter_week1/models/user_model.dart';
import 'package:flutter_week1/screens/main_screen.dart';
import 'setup_page.dart';

class SetupScreen extends StatefulWidget {
  @override
  _SetupScreen createState() => _SetupScreen();
}

class _SetupScreen extends State<SetupScreen> {
  final TextEditingController _nameController = TextEditingController();
  final PageController _pageController = PageController();
  final TextEditingController _bioController = TextEditingController();

  void dispose() {
    _nameController.dispose();
    _pageController.dispose();
    _bioController.dispose();
    super.dispose();
  }

  void _nextPage() {
    _pageController.nextPage(
      duration: Duration(milliseconds: 300),
      curve: Curves.easeInOut,
    );
  }

  void completeSetup() {
    Navigator.of(context).pushReplacement(
      MaterialPageRoute(
        builder: (context) => MainScreen(
          user: UserModel(name: _nameController.text, bio: _bioController.text),
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          Expanded(
            child: PageView(
              controller: _pageController,
              children: [
                SetupPage(
                  title: 'Welcome to the App',
                  content: Column(
                    children: [
                      Text(
                        'This app will help you to manage your daily tasks.',
                        style: TextStyle(fontSize: 18),
                      ),
                      SizedBox(height: 20),
                      ElevatedButton(
                        onPressed: _nextPage,
                        child: Text(
                          'Next',
                          style: TextStyle(color: Colors.white, fontSize: 15),
                        ),
                        style: ElevatedButton.styleFrom(
                          backgroundColor:
                              const Color.fromARGB(255, 94, 180, 250),
                          padding: EdgeInsets.symmetric(
                              horizontal: 150, vertical: 20),
                        ),
                      ),
                    ],
                  ),
                ),
                SetupPage(
                  title: 'What is your name?',
                  content: Column(
                    children: [
                      Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: TextField(
                          controller: _nameController,
                          decoration: InputDecoration(
                            border: OutlineInputBorder(),
                            labelText: 'Name',
                          ),
                        ),
                      ),
                      SizedBox(height: 20),
                      ElevatedButton(
                        onPressed: () {
                          if (_nameController.text.isNotEmpty) {
                            _nextPage();
                          }
                        },
                        child: Text(
                          'Next',
                          style: TextStyle(color: Colors.white, fontSize: 15),
                        ),
                        style: ElevatedButton.styleFrom(
                          backgroundColor:
                              const Color.fromARGB(255, 94, 180, 250),
                          padding: EdgeInsets.symmetric(
                              horizontal: 150, vertical: 20),
                        ),
                      ),
                    ],
                  ),
                ),
                SetupPage(
                    title: 'Introduce yourself',
                    content: Column(
                      children: [
                        Padding(
                          padding: const EdgeInsets.all(8.0),
                          child: TextField(
                            controller: _bioController,
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              labelText: 'Bio',
                            ),
                          ),
                        ),
                        SizedBox(height: 20),
                        ElevatedButton(
                          onPressed: _nextPage,
                          child: Text(
                            'Next',
                            style: TextStyle(color: Colors.white, fontSize: 15),
                          ),
                          style: ElevatedButton.styleFrom(
                            backgroundColor:
                                const Color.fromARGB(255, 94, 180, 250),
                            padding: EdgeInsets.symmetric(
                                horizontal: 150, vertical: 20),
                          ),
                        ),
                      ],
                    )),
                SetupPage(
                  title: 'Start your journey',
                  content: Column(
                    children: [
                      Text(
                        'Thank you ${_nameController.text} for setting up the app.',
                        style: TextStyle(fontSize: 18),
                      ),
                      SizedBox(height: 20),
                      ElevatedButton(
                        onPressed: completeSetup,
                        child: Text(
                          'Start Using the App',
                          style: TextStyle(color: Colors.white, fontSize: 15),
                        ),
                        style: ElevatedButton.styleFrom(
                          backgroundColor:
                              const Color.fromARGB(255, 94, 180, 250),
                          padding: EdgeInsets.symmetric(
                              horizontal: 150, vertical: 20),
                        ),
                      ),
                    ],
                  ),
                ),
              ],
            ),
          )
        ],
      ),
    );
  }
}
